stravalib.util.limiter.get\_rates\_from\_response\_headers
==========================================================

.. currentmodule:: stravalib.util.limiter

.. autofunction:: get_rates_from_response_headers
